@@ -16,11 +16,12 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+//#define TEST_VERBOSE
+#include <birnet/birnettests.h>
 #include <rapicorn/rapicorn.hh>
 
 namespace {
 using namespace Rapicorn;
-using Rapicorn::uint;
 
 static void
 shade_rect_test (uint n)
@@ -36,7 +37,7 @@ extern "C" int
 main (int   argc,
       char *argv[])
 {
-  printf ("TEST: %s:\n", basename (argv[0]));
+  birnet_init_test (&argc, &argv);
   shade_rect_test (argc > 1 ? Birnet::string_to_uint (argv[1]) : 1);
   return 0;
 }
